@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,30 +14,33 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.video.transcoder_v1.services.transcoder_service import pagers
-from google.cloud.video.transcoder_v1.types import resources
-from google.cloud.video.transcoder_v1.types import services
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.rpc import status_pb2  # type: ignore
-from .transports.base import TranscoderServiceTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.video.transcoder_v1.services.transcoder_service import pagers
+from google.cloud.video.transcoder_v1.types import resources, services
+
+from .transports.base import DEFAULT_CLIENT_INFO, TranscoderServiceTransport
 from .transports.grpc import TranscoderServiceGrpcTransport
 from .transports.grpc_asyncio import TranscoderServiceGrpcAsyncIOTransport
 
@@ -57,7 +60,8 @@ class TranscoderServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = TranscoderServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[TranscoderServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -170,10 +174,16 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def job_path(project: str, location: str, job: str,) -> str:
+    def job_path(
+        project: str,
+        location: str,
+        job: str,
+    ) -> str:
         """Returns a fully-qualified job string."""
         return "projects/{project}/locations/{location}/jobs/{job}".format(
-            project=project, location=location, job=job,
+            project=project,
+            location=location,
+            job=job,
         )
 
     @staticmethod
@@ -186,10 +196,16 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def job_template_path(project: str, location: str, job_template: str,) -> str:
+    def job_template_path(
+        project: str,
+        location: str,
+        job_template: str,
+    ) -> str:
         """Returns a fully-qualified job_template string."""
         return "projects/{project}/locations/{location}/jobTemplates/{job_template}".format(
-            project=project, location=location, job_template=job_template,
+            project=project,
+            location=location,
+            job_template=job_template,
         )
 
     @staticmethod
@@ -202,7 +218,9 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -215,9 +233,13 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -226,9 +248,13 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -237,9 +263,13 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -248,10 +278,14 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -260,6 +294,73 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -310,50 +411,22 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, TranscoderServiceTransport):
             # transport is a TranscoderServiceTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -365,6 +438,15 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -375,6 +457,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def create_job(
@@ -389,6 +472,36 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
     ) -> resources.Job:
         r"""Creates a job in the specified region.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud.video import transcoder_v1
+
+            def sample_create_job():
+                # Create a client
+                client = transcoder_v1.TranscoderServiceClient()
+
+                # Initialize request argument(s)
+                job = transcoder_v1.Job()
+                job.template_id = "template_id_value"
+
+                request = transcoder_v1.CreateJobRequest(
+                    parent="parent_value",
+                    job=job,
+                )
+
+                # Make the request
+                response = client.create_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.video.transcoder_v1.types.CreateJobRequest, dict]):
                 The request object. Request message for
@@ -418,7 +531,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 Transcoding job resource.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, job])
         if request is not None and has_flattened_params:
@@ -451,7 +564,12 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -467,6 +585,33 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
     ) -> pagers.ListJobsPager:
         r"""Lists jobs in the specified region.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud.video import transcoder_v1
+
+            def sample_list_jobs():
+                # Create a client
+                client = transcoder_v1.TranscoderServiceClient()
+
+                # Initialize request argument(s)
+                request = transcoder_v1.ListJobsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_jobs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.video.transcoder_v1.types.ListJobsRequest, dict]):
                 The request object. Request message for
@@ -494,7 +639,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -525,12 +670,20 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListJobsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -547,6 +700,32 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
     ) -> resources.Job:
         r"""Returns the job data.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud.video import transcoder_v1
+
+            def sample_get_job():
+                # Create a client
+                client = transcoder_v1.TranscoderServiceClient()
+
+                # Initialize request argument(s)
+                request = transcoder_v1.GetJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.video.transcoder_v1.types.GetJobRequest, dict]):
                 The request object. Request message for
@@ -569,7 +748,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 Transcoding job resource.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -600,7 +779,12 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -616,6 +800,29 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
     ) -> None:
         r"""Deletes a job.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud.video import transcoder_v1
+
+            def sample_delete_job():
+                # Create a client
+                client = transcoder_v1.TranscoderServiceClient()
+
+                # Initialize request argument(s)
+                request = transcoder_v1.DeleteJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_job(request=request)
+
         Args:
             request (Union[google.cloud.video.transcoder_v1.types.DeleteJobRequest, dict]):
                 The request object. Request message for
@@ -634,7 +841,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -666,7 +873,10 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def create_job_template(
@@ -682,6 +892,33 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
     ) -> resources.JobTemplate:
         r"""Creates a job template in the specified region.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud.video import transcoder_v1
+
+            def sample_create_job_template():
+                # Create a client
+                client = transcoder_v1.TranscoderServiceClient()
+
+                # Initialize request argument(s)
+                request = transcoder_v1.CreateJobTemplateRequest(
+                    parent="parent_value",
+                    job_template_id="job_template_id_value",
+                )
+
+                # Make the request
+                response = client.create_job_template(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.video.transcoder_v1.types.CreateJobTemplateRequest, dict]):
                 The request object. Request message for
@@ -724,7 +961,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 Transcoding job template resource.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, job_template, job_template_id])
         if request is not None and has_flattened_params:
@@ -759,7 +996,12 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -775,6 +1017,33 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
     ) -> pagers.ListJobTemplatesPager:
         r"""Lists job templates in the specified region.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud.video import transcoder_v1
+
+            def sample_list_job_templates():
+                # Create a client
+                client = transcoder_v1.TranscoderServiceClient()
+
+                # Initialize request argument(s)
+                request = transcoder_v1.ListJobTemplatesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_job_templates(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.video.transcoder_v1.types.ListJobTemplatesRequest, dict]):
                 The request object. Request message for
@@ -802,7 +1071,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -833,12 +1102,20 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListJobTemplatesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -855,6 +1132,32 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
     ) -> resources.JobTemplate:
         r"""Returns the job template data.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud.video import transcoder_v1
+
+            def sample_get_job_template():
+                # Create a client
+                client = transcoder_v1.TranscoderServiceClient()
+
+                # Initialize request argument(s)
+                request = transcoder_v1.GetJobTemplateRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_job_template(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.video.transcoder_v1.types.GetJobTemplateRequest, dict]):
                 The request object. Request message for
@@ -878,7 +1181,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 Transcoding job template resource.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -909,7 +1212,12 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -925,6 +1233,29 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
     ) -> None:
         r"""Deletes a job template.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud.video import transcoder_v1
+
+            def sample_delete_job_template():
+                # Create a client
+                client = transcoder_v1.TranscoderServiceClient()
+
+                # Initialize request argument(s)
+                request = transcoder_v1.DeleteJobTemplateRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_job_template(request=request)
+
         Args:
             request (Union[google.cloud.video.transcoder_v1.types.DeleteJobTemplateRequest, dict]):
                 The request object. Request message for
@@ -943,7 +1274,7 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -975,7 +1306,10 @@ class TranscoderServiceClient(metaclass=TranscoderServiceClientMeta):
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def __enter__(self):
